/* GNIO - GLib Network Layer of GIO
 * 
 * Copyright (C) 2008 Christian Kellner, Samuel Cormier-Iijima
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors: Christian Kellner <gicmo@gnome.org>
 *          Samuel Cormier-Iijima <sciyoshi@gmail.com>
 */

#include <config.h>
#include <string.h>
#include <glib.h>

#include "ginet6address.h"

G_DEFINE_TYPE (GInet6Address, g_inet6_address, G_TYPE_INET_ADDRESS);

struct _GInet6AddressPrivate {
  union {
    guint8  u6_addr8[16];
    guint16 u6_addr16[8];
    guint32 u6_addr32[4];
  } addr;
};

static void
g_inet6_address_finalize (GObject *object)
{
  GInet6Address *address G_GNUC_UNUSED = G_INET6_ADDRESS (object);

  if (G_OBJECT_CLASS (g_inet6_address_parent_class)->finalize)
    (*G_OBJECT_CLASS (g_inet6_address_parent_class)->finalize) (object);
}

static void
g_inet6_address_dispose (GObject *object)
{
  GInet6Address *address G_GNUC_UNUSED = G_INET6_ADDRESS (object);

  if (G_OBJECT_CLASS (g_inet6_address_parent_class)->dispose)
    (*G_OBJECT_CLASS (g_inet6_address_parent_class)->dispose) (object);
}

static void
g_inet6_address_class_init (GInet6AddressClass *klass)
{
  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);

  g_type_class_add_private (klass, sizeof (GInet6AddressPrivate));

  gobject_class->finalize = g_inet6_address_finalize;
  gobject_class->dispose = g_inet6_address_dispose;
}

static void
g_inet6_address_init (GInet6Address *address)
{
  address->priv = G_TYPE_INSTANCE_GET_PRIVATE (address,
                                               G_TYPE_INET6_ADDRESS,
                                               GInet6AddressPrivate);
}

/* ************************************************************************* */
/* Public Functions */

GInet6Address *
g_inet6_address_from_string (const char *string)
{
  return NULL;
}

char *
g_inet6_address_to_string (GInet6Address *address)
{
  return NULL;
}

GInet6Address *
g_inet6_address_from_bytes (guint8 bytes[])
{
  GInet6Address *address = G_INET6_ADDRESS (g_object_new (G_TYPE_INET6_ADDRESS, NULL));

  g_memmove (address->priv->addr.u6_addr8, bytes, 16);

  return address;
}

const guint8 *
g_inet6_address_to_bytes (GInet6Address *address)
{
  return NULL;
}

GInet6Address *
g_inet6_address_new_loopback (void)
{
  guint8 bytes[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1};

  return g_inet6_address_from_bytes (bytes);
}

GInet6Address *
g_inet6_address_new_any (void)
{
  return NULL; 
}
