/* GNIO - GLib Network Layer of GIO
 *
 * Copyright (C) 2008 Christian Kellner, Samuel Cormier-Iijima
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors: Christian Kellner <gicmo@gnome.org>
 *          Samuel Cormier-Iijima <sciyoshi@gmail.com>
 */

#ifndef G_INET_ADDRESS_H
#define G_INET_ADDRESS_H

#include <glib-object.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define G_TYPE_INET_ADDRESS         (g_inet_address_get_type ())
#define G_INET_ADDRESS(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), G_TYPE_INET_ADDRESS, GInetAddress))
#define G_INET_ADDRESS_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), G_TYPE_INET_ADDRESS, GInetAddressClass))
#define G_IS_INET_ADDRESS(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), G_TYPE_INET_ADDRESS))
#define G_IS_INET_ADDRESS_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), G_TYPE_INET_ADDRESS))
#define G_INET_ADDRESS_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), G_TYPE_INET_ADDRESS, GInetAddressClass))

typedef struct _GInetAddress        GInetAddress;
typedef struct _GInetAddressClass   GInetAddressClass;

struct _GInetAddress
{
  GObject parent;
};

struct _GInetAddressClass
{
  GObjectClass parent_class;

  gboolean (*is_any) (GInetAddress *address);
  gboolean (*is_linklocal) (GInetAddress *address);
  gboolean (*is_loopback) (GInetAddress *address);
  gboolean (*is_sitelocal) (GInetAddress *address);
  gboolean (*is_multicast) (GInetAddress *address);
  gboolean (*is_mc_global) (GInetAddress *address);
  gboolean (*is_mc_linklocal) (GInetAddress *address);
  gboolean (*is_mc_nodelocal) (GInetAddress *address);
  gboolean (*is_mc_orglocal) (GInetAddress *address);
  gboolean (*is_mc_sitelocal) (GInetAddress *address);
};

GType          g_inet_address_get_type         (void) G_GNUC_CONST;

/* accessors to gobject properties that get overridden by subclasses */
gboolean 	g_inet_address_is_any          (GInetAddress *address);

gboolean 	g_inet_address_is_linklocal    (GInetAddress *address);

gboolean 	g_inet_address_is_loopback     (GInetAddress *address);

gboolean 	g_inet_address_is_sitelocal    (GInetAddress *address);

gboolean 	g_inet_address_is_multicast    (GInetAddress *address);

gboolean 	g_inet_address_is_mc_global    (GInetAddress *address);

gboolean 	g_inet_address_is_mc_linklocal (GInetAddress *address);

gboolean 	g_inet_address_is_mc_nodelocal (GInetAddress *address);

gboolean 	g_inet_address_is_mc_orglocal  (GInetAddress *address);

gboolean 	g_inet_address_is_mc_sitelocal (GInetAddress *address);

G_END_DECLS

#endif /* G_INET_ADDRESS_H */

